/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.ddl.dataconnector.desc;

import java.io.Serializable;

import org.apache.hadoop.fs.Path;
import org.apache.hadoop.hive.ql.ddl.DDLDesc;
import org.apache.hadoop.hive.ql.plan.Explain;
import org.apache.hadoop.hive.ql.plan.Explain.Level;

/**
 * DDL task description for DESC CONNECTOR commands.
 */
@Explain(displayName = "Describe Connector", explainLevels = { Level.USER, Level.DEFAULT, Level.EXTENDED })
public class DescDataConnectorDesc implements DDLDesc, Serializable {
  private static final long serialVersionUID = 1L;

  public static final String DESC_DATACONNECTOR_SCHEMA =
      "name,type,url,owner_name,owner_type,comment#string:string:string:string:string:string";

  public static final String DESC_DATACONNECTOR_SCHEMA_EXTENDED =
      "name,type,url,owner_name,owner_type,comment,parameters#" +
      "string:string:string:string:string:string,string";

  private final String resFile;
  private final String dcName;
  private final boolean isExtended;

  public DescDataConnectorDesc(Path resFile, String dcName, boolean isExtended) {
    this.resFile = resFile.toString();
    this.dcName = dcName;
    this.isExtended = isExtended;
  }

  @Explain(displayName = "extended", displayOnlyOnTrue=true,
      explainLevels = { Level.USER, Level.DEFAULT, Level.EXTENDED })
  public boolean isExtended() {
    return isExtended;
  }

  @Explain(displayName = "connector", explainLevels = { Level.USER, Level.DEFAULT, Level.EXTENDED })
  public String getConnectorName() {
    return dcName;
  }

  @Explain(displayName = "result file", explainLevels = { Level.EXTENDED })
  public String getResFile() {
    return resFile;
  }

  public String getSchema() {
    return isExtended ? DESC_DATACONNECTOR_SCHEMA_EXTENDED : DESC_DATACONNECTOR_SCHEMA;
  }
}
